cypari2: Python interface to the number theory library libpari
==============================================================

Description
-----------

A Python interface to the number theory library libpari.

License
-------

GPL version 2 or later


Upstream Contact
----------------

https://github.com/defeo/cypari2
